<?php

require_once __DIR__ . '/config.php';
require_once __DIR__ . '/functions.php';

$updateJson = file_get_contents('php://input');
$update = json_decode($updateJson, true);

if (!$update) {
    exit;
}

if (isset($update['message'])) {
    $message = $update['message'];
    $chatId = $message['chat']['id'];
    $userId = $message['from']['id'];
    $text = isset($message['text']) ? trim($message['text']) : '';

    if (!isUserAuthorized($userId)) {
         sendTelegramMessage($chatId, "Anda tidak diizinkan menggunakan bot ini.");
         exit;
    }

    if (strpos($text, '/') === 0) {
        $parts = explode(' ', $text, 2);
        $command = strtolower($parts[0]);
        $argument = isset($parts[1]) ? trim($parts[1]) : '';

        $domains = readJsonFile(DOMAIN_DATA_FILE);
        $blockedDomains = readJsonFile(BLOCKED_LIST_FILE);
        $paths = readJsonFile(PATH_LIST_FILE);

        switch ($command) {
            case '/help':
                $helpText = "Perintah:\n";
                $helpText .= "/help - Bantuan\n";
                $helpText .= "/info - Info domain aktif\n";
                $helpText .= "/infopath - Info path URL\n";
                $helpText .= "/add <domain> <brand> <label> [nama] - Tambah domain\n";
                $helpText .= "/addpath <label> <path> - Tambah path URL\n";
                $helpText .= "/show <domain> - Aktifkan domain\n";
                $helpText .= "/hide <domain> - Sembunyikan domain\n";
                $helpText .= "/stop <domain> - Blokir domain\n";
                $helpText .= "/move <domain> <brand> <label> - Pindah brand/label\n";
                $helpText .= "/check <domain> - Cek status domain\n";
                $helpText .= "/primary <domain> - Set domain utama (tdk diimplementasi)\n";
                $helpText .= "/primarypath <path> - Set path utama (tdk diimplementasi)\n";
                $helpText .= "/blacklist - Lihat domain diblokir\n";
                $helpText .= "/remove <domain> - Hapus domain permanen\n";
                $helpText .= "/removepath <label> <path> - Hapus path permanen\n";
                sendTelegramMessage($chatId, $helpText);
                break;

            case '/info':
                $activeDomains = array_filter($domains, function($d) {
                    return isset($d['status']) && $d['status'] === 'active';
                });
                if (empty($activeDomains)) {
                    sendTelegramMessage($chatId, "Tidak ada domain aktif.");
                } else {
                    $responseText = "Domain Aktif:\n";
                    foreach ($activeDomains as $domain) {
                         $responseText .= "- " . ($domain['nama'] ?? $domain['domain']) . " (" . $domain['domain'] . ") [".$domain['brand']."/".$domain['label']."]\n";
                    }
                    sendTelegramMessage($chatId, $responseText);
                }
                break;

            case '/infopath':
                 if (empty($paths)) {
                    sendTelegramMessage($chatId, "Tidak ada path URL tersimpan.");
                } else {
                    $responseText = "Daftar Path URL:\n";
                     foreach ($paths as $label => $pathList) {
                         $responseText .= "*Label: $label*\n";
                         if (is_array($pathList)) {
                             foreach($pathList as $path) {
                                $responseText .= "- `$path`\n";
                             }
                         }
                         $responseText .= "\n";
                     }
                     sendTelegramMessage($chatId, $responseText);
                }
                break;

            case '/add':
                $addParts = explode(' ', $argument, 4);
                if (count($addParts) < 3) {
                     sendTelegramMessage($chatId, "Format: /add <domain> <brand> <label> [nama]");
                     break;
                 }
                $domain = strtolower(trim($addParts[0]));
                $brand = trim($addParts[1]);
                $label = trim($addParts[2]);
                $nama = trim($addParts[3] ?? $domain);

                $exists = false;
                foreach($domains as $d) { if ($d['domain'] === $domain) { $exists = true; break; } }

                if ($exists) {
                     sendTelegramMessage($chatId, "Error: Domain '$domain' sudah ada.");
                     break;
                }

                $statusCheck = checkDomainStatus($domain);
                $initialStatus = 'active';
                $dns_id = null;

                if ($statusCheck['status'] === 'blocked') {
                    $initialStatus = 'blocked';
                     sendTelegramMessage($chatId, "Info: Domain '$domain' terdeteksi diblokir saat dicek. Ditambahkan dengan status 'blocked'. Tidak ada DNS record dibuat.");
                     if (!in_array($domain, $blockedDomains)) {
                         $blockedDomains[] = $domain;
                         writeJsonFile(BLOCKED_LIST_FILE, $blockedDomains);
                     }
                } else {
                    $dns_id = addCloudflareCname($domain);
                    if ($dns_id === null) {
                        sendTelegramMessage($chatId, "Peringatan: Gagal menambahkan record DNS di Cloudflare untuk $domain. Domain ditambahkan ke list tapi mungkin tidak bisa diakses via rotator.");
                    }
                }

                $newDomain = [
                     "domain" => $domain, "nama" => $nama, "brand" => $brand, "label" => $label,
                     "status" => $initialStatus, "cloudflare_dns_id" => $dns_id
                 ];
                $domains[] = $newDomain;
                if (writeJsonFile(DOMAIN_DATA_FILE, $domains)) {
                     sendTelegramMessage($chatId, "Sukses: Domain '$domain' ditambahkan (Brand: $brand, Label: $label, Status: $initialStatus, DNS ID: " . ($dns_id ?? 'N/A') . ")");
                 } else {
                     sendTelegramMessage($chatId, "Error: Gagal menyimpan data domain.");
                     if ($dns_id !== null) {
                         deleteCloudflareDnsRecord($dns_id);
                     }
                 }
                 break;

            case '/addpath':
                 $pathParts = explode(' ', $argument, 2);
                 if (count($pathParts) < 2) {
                     sendTelegramMessage($chatId, "Format: /addpath <label> <path>");
                     break;
                 }
                 $label = trim($pathParts[0]);
                 $path = trim($pathParts[1]);

                 if (!isset($paths[$label])) {
                     $paths[$label] = [];
                 }
                 if (!in_array($path, $paths[$label])) {
                    $paths[$label][] = $path;
                    if (writeJsonFile(PATH_LIST_FILE, $paths)) {
                         sendTelegramMessage($chatId, "Sukses: Path '$path' ditambahkan ke label '$label'.");
                    } else {
                         sendTelegramMessage($chatId, "Error: Gagal menyimpan data path.");
                    }
                 } else {
                     sendTelegramMessage($chatId, "Info: Path '$path' sudah ada di label '$label'.");
                 }
                break;

            case '/show':
            case '/hide':
            case '/stop':
                 if (empty($argument)) {
                     sendTelegramMessage($chatId, "Format: /$command <domain>");
                     break;
                 }
                 $domainToManage = strtolower(trim($argument));
                 $found = false;
                 $updated = false;
                 $dnsActionNeeded = false;
                 $dnsIdToDelete = null;
                 $originalStatus = '';

                 foreach ($domains as $key => $d) {
                     if ($d['domain'] === $domainToManage) {
                         $found = true;
                         $originalStatus = $d['status'];
                         $newStatus = $originalStatus;

                         if ($command === '/show' && $originalStatus !== 'active') {
                             $newStatus = 'active';
                             $dnsActionNeeded = true;
                         } elseif ($command === '/hide' && $originalStatus !== 'hidden') {
                              $newStatus = 'hidden';
                              $dnsActionNeeded = true;
                              $dnsIdToDelete = $d['cloudflare_dns_id'] ?? null;
                         } elseif ($command === '/stop' && $originalStatus !== 'blocked') {
                              $newStatus = 'blocked';
                              $dnsActionNeeded = true;
                              $dnsIdToDelete = $d['cloudflare_dns_id'] ?? null;
                         }

                         if ($newStatus !== $originalStatus) {
                             $domains[$key]['status'] = $newStatus;

                             if ($dnsActionNeeded) {
                                 if ($newStatus === 'active') {
                                     $newDnsId = addCloudflareCname($domainToManage);
                                     if ($newDnsId) {
                                         $domains[$key]['cloudflare_dns_id'] = $newDnsId;
                                         sendTelegramMessage($chatId, "Info: Record DNS dibuat/diperbarui untuk $domainToManage (ID: $newDnsId).");
                                     } else {
                                         sendTelegramMessage($chatId, "Peringatan: Gagal membuat/memperbarui record DNS untuk $domainToManage saat mengaktifkan.");
                                         $domains[$key]['cloudflare_dns_id'] = null;
                                     }
                                 } elseif (($newStatus === 'hidden' || $newStatus === 'blocked') && !empty($dnsIdToDelete)) {
                                     if (deleteCloudflareDnsRecord($dnsIdToDelete)) {
                                         $domains[$key]['cloudflare_dns_id'] = null;
                                         sendTelegramMessage($chatId, "Info: Record DNS (ID: $dnsIdToDelete) dihapus untuk $domainToManage.");
                                     } else {
                                          sendTelegramMessage($chatId, "Peringatan: Gagal menghapus record DNS (ID: $dnsIdToDelete) untuk $domainToManage.");
                                     }
                                 }
                             }

                             if ($newStatus === 'blocked' && !in_array($domainToManage, $blockedDomains)) {
                                 $blockedDomains[] = $domainToManage;
                                 writeJsonFile(BLOCKED_LIST_FILE, $blockedDomains);
                             } elseif ($newStatus !== 'blocked' && ($key_blocked = array_search($domainToManage, $blockedDomains)) !== false) {
                                 unset($blockedDomains[$key_blocked]);
                                 writeJsonFile(BLOCKED_LIST_FILE, array_values($blockedDomains));
                             }

                             if (writeJsonFile(DOMAIN_DATA_FILE, $domains)) {
                                 sendTelegramMessage($chatId, "Sukses: Status domain '$domainToManage' diubah menjadi '$newStatus'.");
                                 $updated = true;
                             } else {
                                 sendTelegramMessage($chatId, "Error: Gagal menyimpan perubahan status domain.");
                             }
                         } else {
                             sendTelegramMessage($chatId, "Info: Domain '$domainToManage' sudah dalam status '$originalStatus'.");
                             $updated = true;
                         }
                         break;
                     }
                 }
                 if (!$found) {
                     sendTelegramMessage($chatId, "Error: Domain '$domainToManage' tidak ditemukan.");
                 }
                 break;

            case '/move':
                 $moveParts = explode(' ', $argument, 3);
                 if (count($moveParts) < 3) {
                     sendTelegramMessage($chatId, "Format: /move <domain> <brand_baru> <label_baru>");
                     break;
                 }
                 $domainToMove = strtolower(trim($moveParts[0]));
                 $newBrand = trim($moveParts[1]);
                 $newLabel = trim($moveParts[2]);
                 $found = false;
                 $updated = false;

                 foreach ($domains as $key => $d) {
                     if ($d['domain'] === $domainToMove) {
                         $found = true;
                         if ($d['brand'] !== $newBrand || $d['label'] !== $newLabel) {
                             $domains[$key]['brand'] = $newBrand;
                             $domains[$key]['label'] = $newLabel;
                             if (writeJsonFile(DOMAIN_DATA_FILE, $domains)) {
                                 sendTelegramMessage($chatId, "Sukses: Domain '$domainToMove' dipindahkan ke Brand '$newBrand' / Label '$newLabel'.");
                                 $updated = true;
                             } else {
                                 sendTelegramMessage($chatId, "Error: Gagal menyimpan perubahan brand/label.");
                             }
                         } else {
                             sendTelegramMessage($chatId, "Info: Domain '$domainToMove' sudah berada di Brand/Label tersebut.");
                              $updated = true;
                         }
                         break;
                     }
                 }
                 if (!$found) {
                     sendTelegramMessage($chatId, "Error: Domain '$domainToMove' tidak ditemukan.");
                 }
                 break;

             case '/check':
                 if (empty($argument)) {
                     sendTelegramMessage($chatId, "Format: /check <domain>");
                     break;
                 }
                 $domainToCheck = strtolower(trim($argument));
                 $result = checkDomainStatus($domainToCheck);
                 sendTelegramMessage($chatId, "Status Domain: $domainToCheck\n" . $result['message']);
                 break;

            case '/primary':
            case '/primarypath':
                 sendTelegramMessage($chatId, "Fitur '$command' belum diimplementasikan sepenuhnya.");
                 break;

            case '/blacklist':
                 if (empty($blockedDomains)) {
                     sendTelegramMessage($chatId, "Daftar blacklist kosong.");
                 } else {
                     $responseText = "Domain Diblokir (dari " . BLOCKED_LIST_FILE . "):\n";
                     foreach ($blockedDomains as $domain) {
                          $responseText .= "- $domain\n";
                     }
                     $blockedFromLabeled = array_filter($domains, function($d) { return isset($d['status']) && $d['status'] === 'blocked'; });
                     if (!empty($blockedFromLabeled)) {
                         $responseText .= "\nDomain dengan status 'blocked' (dari ". basename(DOMAIN_DATA_FILE) ."):\n";
                         foreach($blockedFromLabeled as $d) {
                            $responseText .= "- " . $d['domain'] . "\n";
                         }
                     }
                     sendTelegramMessage($chatId, $responseText);
                 }
                break;

            case '/remove':
                if (empty($argument)) {
                     sendTelegramMessage($chatId, "Format: /remove <domain>");
                     break;
                 }
                $domainToRemove = strtolower(trim($argument));
                $found = false;
                $dnsIdToDelete = null;

                foreach ($domains as $key => $d) {
                    if ($d['domain'] === $domainToRemove) {
                        $found = true;
                        $dnsIdToDelete = $d['cloudflare_dns_id'] ?? null;
                        unset($domains[$key]);

                        if ($dnsIdToDelete) {
                            if (deleteCloudflareDnsRecord($dnsIdToDelete)) {
                                sendTelegramMessage($chatId, "Info: Record DNS (ID: $dnsIdToDelete) untuk $domainToRemove telah dihapus.");
                            } else {
                                sendTelegramMessage($chatId, "Peringatan: Gagal menghapus record DNS (ID: $dnsIdToDelete) untuk $domainToRemove. Mungkin perlu dihapus manual di Cloudflare.");
                            }
                        }

                        if (writeJsonFile(DOMAIN_DATA_FILE, array_values($domains))) {
                             sendTelegramMessage($chatId, "Sukses: Domain '$domainToRemove' dihapus permanen dari daftar utama.");
                             if (($key_blocked = array_search($domainToRemove, $blockedDomains)) !== false) {
                                 unset($blockedDomains[$key_blocked]);
                                 writeJsonFile(BLOCKED_LIST_FILE, array_values($blockedDomains));
                             }
                        } else {
                             sendTelegramMessage($chatId, "Error: Gagal menyimpan perubahan setelah menghapus domain '$domainToRemove'.");
                        }
                        break;
                    }
                }
                 if (!$found) {
                     sendTelegramMessage($chatId, "Error: Domain '$domainToRemove' tidak ditemukan di daftar utama.");
                 }
                break;

            case '/removepath':
                 $removePathParts = explode(' ', $argument, 2);
                 if (count($removePathParts) < 2) {
                     sendTelegramMessage($chatId, "Format: /removepath <label> <path>");
                     break;
                 }
                 $label = trim($removePathParts[0]);
                 $pathToRemove = trim($removePathParts[1]);
                 $updated = false;

                 if (isset($paths[$label]) && is_array($paths[$label])) {
                     $initialCount = count($paths[$label]);
                     $paths[$label] = array_filter($paths[$label], function($p) use ($pathToRemove) {
                         return $p !== $pathToRemove;
                     });

                     if (count($paths[$label]) < $initialCount) {
                         if (empty($paths[$label])) {
                             unset($paths[$label]);
                         }
                         if (writeJsonFile(PATH_LIST_FILE, $paths)) {
                             sendTelegramMessage($chatId, "Sukses: Path '$pathToRemove' dihapus dari label '$label'.");
                             $updated = true;
                         } else {
                             sendTelegramMessage($chatId, "Error: Gagal menyimpan data path setelah penghapusan.");
                         }
                     } else {
                         sendTelegramMessage($chatId, "Error: Path '$pathToRemove' tidak ditemukan di label '$label'.");
                         $updated = true;
                     }
                 } else {
                     sendTelegramMessage($chatId, "Error: Label '$label' tidak ditemukan.");
                 }
                break;

            default:
                sendTelegramMessage($chatId, "Perintah tidak dikenali: $command");
                break;
        }
    }
}

?>
