<?php
if (!defined('BOT_TOKEN')) {
   die('Akses langsung tidak diizinkan.');
}

$totalDomains = count($domains);
$statusCounts = ['active' => 0, 'hidden' => 0, 'blocked' => 0, 'unknown' => 0];
$brandCounts = [];
$labelCounts = [];

foreach ($domains as $d) {
    $status = $d['status'] ?? 'unknown';
    if (isset($statusCounts[$status])) {
        $statusCounts[$status]++;
    } else {
        $statusCounts['unknown']++;
    }

    $brand = $d['brand'] ?? 'N/A';
    $label = $d['label'] ?? 'N/A';
    $brandCounts[$brand] = ($brandCounts[$brand] ?? 0) + 1;
    $labelCounts[$label] = ($labelCounts[$label] ?? 0) + 1;
}

$totalBlockedExplicit = count($blockedDomains);
$totalPaths = 0;
$totalLabelsWithPath = count($paths);
foreach ($paths as $label => $pathList) {
    if(is_array($pathList)) {
        $totalPaths += count($pathList);
    }
}

$webhookInfo = getWebhookInfo();
$webhookStatus = ['ok' => false, 'message' => 'Error cek status', 'color_class' => 'status-error'];
if ($webhookInfo['ok'] && isset($webhookInfo['result']['url'])) {
    if (!empty($webhookInfo['result']['url'])) {
        $webhookStatus = ['ok' => true, 'message' => 'Aktif: ' . basename($webhookInfo['result']['url']), 'color_class' => 'status-ok'];
         if (isset($webhookInfo['result']['last_error_message'])) {
             $webhookStatus['message'] .= '<br><small style="color:red;">Error Terakhir: ' . htmlspecialchars($webhookInfo['result']['last_error_message']) . '</small>';
             $webhookStatus['color_class'] = 'status-warning';
         }
    } else {
        $webhookStatus = ['ok' => true, 'message' => 'Webhook tidak aktif', 'color_class' => 'status-warning'];
    }
} else {
     $webhookStatus['message'] = $webhookInfo['error'] ?? 'Error tidak diketahui saat cek webhook.';
}


$cloudflareStatus = testCloudflareConnection();
$cfStatus = ['ok' => $cloudflareStatus['ok'] ?? false, 'message' => 'N/A', 'color_class' => 'status-error'];
if($cfStatus['ok']) {
    $cfStatus['message'] = $cloudflareStatus['message'] ?? 'Koneksi Berhasil';
    $cfStatus['color_class'] = 'status-ok';
} else {
    $cfStatus['message'] = $cloudflareStatus['error'] ?? 'Koneksi Gagal';
}

?>

<h1><i class="fas fa-tachometer-alt"></i> Dashboard</h1>

<div class="container">
    <h2>Statistik Domain</h2>
    <div class="dashboard-cards">
        <div class="card">
            <i class="fas fa-globe"></i>
            <div class="card-content">
                <div class="card-title">Total Domain</div>
                <div class="card-value"><?php echo $totalDomains; ?></div>
            </div>
        </div>
        <div class="card status-ok">
            <i class="fas fa-check-circle"></i>
            <div class="card-content">
                <div class="card-title">Domain Aktif</div>
                <div class="card-value"><?php echo $statusCounts['active']; ?></div>
            </div>
        </div>
         <div class="card status-warning">
            <i class="fas fa-eye-slash"></i>
            <div class="card-content">
                <div class="card-title">Domain Hidden</div>
                <div class="card-value"><?php echo $statusCounts['hidden']; ?></div>
            </div>
        </div>
        <div class="card status-error">
            <i class="fas fa-ban"></i>
            <div class="card-content">
                <div class="card-title">Domain Blocked</div>
                <div class="card-value"><?php echo $statusCounts['blocked']; ?></div>
                 <?php if ($statusCounts['blocked'] !== $totalBlockedExplicit): ?>
                    <small style="color: red;">(Warning: Jumlah di blocked.json (<?php echo $totalBlockedExplicit; ?>) berbeda)</small>
                <?php endif; ?>
            </div>
        </div>
        <div class="card">
             <i class="fas fa-tags"></i>
            <div class="card-content">
                <div class="card-title">Total Brand</div>
                <div class="card-value"><?php echo count($brandCounts); ?></div>
            </div>
        </div>
         <div class="card">
             <i class="fas fa-bookmark"></i>
            <div class="card-content">
                <div class="card-title">Total Label</div>
                <div class="card-value"><?php echo count($labelCounts); ?></div>
            </div>
        </div>
    </div>

     <h2>Statistik Path URL</h2>
      <div class="dashboard-cards">
         <div class="card">
            <i class="fas fa-route"></i>
            <div class="card-content">
                <div class="card-title">Total Path</div>
                <div class="card-value"><?php echo $totalPaths; ?></div>
            </div>
        </div>
         <div class="card">
            <i class="fas fa-folder"></i>
            <div class="card-content">
                <div class="card-title">Jumlah Label Path</div>
                <div class="card-value"><?php echo $totalLabelsWithPath; ?></div>
            </div>
        </div>
     </div>

    <h2>Status Sistem</h2>
     <div class="dashboard-cards">
         <div class="card <?php echo $webhookStatus['color_class']; ?>">
            <i class="fab fa-telegram-plane"></i>
            <div class="card-content">
                <div class="card-title">Telegram Webhook</div>
                <div class="card-value" style="font-size: 1.2em; font-weight:normal;"><?php echo $webhookStatus['message']; ?></div>
            </div>
        </div>
         <div class="card <?php echo $cfStatus['color_class']; ?>">
             <i class="fas fa-cloud"></i>
            <div class="card-content">
                <div class="card-title">Cloudflare API</div>
                <div class="card-value" style="font-size: 1.2em; font-weight:normal;"><?php echo htmlspecialchars($cfStatus['message']); ?></div>
            </div>
        </div>
     </div>
</div>

<div class="container">
    <h2>Ringkasan Brand & Label</h2>
    <div style="display: flex; flex-wrap: wrap; gap: 30px;">
        <div style="flex: 1; min-width: 250px;">
            <h3>Domain per Brand</h3>
            <?php if (!empty($brandCounts)): ?>
            <table>
                <thead><tr><th>Brand</th><th>Jumlah</th></tr></thead>
                <tbody>
                    <?php arsort($brandCounts); foreach($brandCounts as $brand => $count): ?>
                    <tr><td><?php echo htmlspecialchars($brand); ?></td><td><?php echo $count; ?></td></tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
            <?php else: ?>
            <p>Belum ada data brand.</p>
            <?php endif; ?>
        </div>
        <div style="flex: 1; min-width: 250px;">
            <h3>Domain per Label</h3>
             <?php if (!empty($labelCounts)): ?>
            <table>
                <thead><tr><th>Label</th><th>Jumlah</th></tr></thead>
                <tbody>
                     <?php arsort($labelCounts); foreach($labelCounts as $label => $count): ?>
                    <tr><td><?php echo htmlspecialchars($label); ?></td><td><?php echo $count; ?></td></tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
             <?php else: ?>
            <p>Belum ada data label.</p>
            <?php endif; ?>
        </div>
    </div>
</div>
