<?php
if (!defined('BOT_TOKEN')) { die('Akses langsung tidak diizinkan.'); }

$formMessage = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $domains = readJsonFile(DOMAIN_DATA_FILE);
    $blockedDomains = readJsonFile(BLOCKED_LIST_FILE);

    $action = $_POST['action'] ?? '';
    $domain = isset($_POST['domain']) ? strtolower(trim($_POST['domain'])) : '';
    $nama = trim($_POST['nama'] ?? '');
    $brand = trim($_POST['brand'] ?? '');
    $label = trim($_POST['label'] ?? '');
    $status = $_POST['status'] ?? 'active';
    $domainIndex = $_POST['domain_index'] ?? null;
    $cloudflare_target = CLOUDFLARE_DEFAULT_TARGET;

    $resultMessage = '';

    if ($action === 'add_domain' && !empty($domain) && !empty($brand) && !empty($label)) {
         $exists = false; foreach($domains as $d) { if ($d['domain'] === $domain) { $exists = true; break; } }
         if (!$exists) {
             $statusCheck = checkDomainStatus($domain); $initialStatus = 'active'; $dns_id = null;
             if ($statusCheck['status'] === 'blocked') {
                 $initialStatus = 'blocked'; $resultMessage .= "Info: Domain '$domain' terdeteksi diblokir. Status diset 'blocked'. ";
                 if (!in_array($domain, $blockedDomains)) { $blockedDomains[] = $domain; writeJsonFile(BLOCKED_LIST_FILE, $blockedDomains); }
             } else {
                 $dns_id = addCloudflareCname($domain, $cloudflare_target);
                 if ($dns_id === null) { $resultMessage .= "Peringatan: Gagal buat DNS Cloudflare. "; }
                 else { $resultMessage .= "Info: DNS Cloudflare dibuat (ID: $dns_id). "; }
             }
             $newDomain = ["domain" => $domain, "nama" => $nama ?: $domain, "brand" => $brand, "label" => $label, "status" => $initialStatus, "cloudflare_dns_id" => $dns_id];
             $domains[] = $newDomain;
             if (writeJsonFile(DOMAIN_DATA_FILE, $domains)) { $resultMessage .= "Sukses: Domain '$domain' ditambahkan."; }
             else { $resultMessage .= "Error: Gagal menyimpan data domain."; if ($dns_id !== null) { deleteCloudflareDnsRecord($dns_id); } }
         } else { $resultMessage = "Error: Domain '$domain' sudah ada."; }

    } elseif ($action === 'update_domain' && $domainIndex !== null && isset($domains[$domainIndex])) {
         $currentDomainData = $domains[$domainIndex]; $originalStatus = $currentDomainData['status']; $originalDnsId = $currentDomainData['cloudflare_dns_id'] ?? null;
         $domains[$domainIndex]['nama'] = $nama ?: $domain; $domains[$domainIndex]['brand'] = $brand; $domains[$domainIndex]['label'] = $label; $domains[$domainIndex]['status'] = $status;
         if ($status !== $originalStatus) {
             if ($status === 'active' && empty($originalDnsId)) {
                  $newDnsId = addCloudflareCname($currentDomainData['domain'], $cloudflare_target);
                  if ($newDnsId) { $domains[$domainIndex]['cloudflare_dns_id'] = $newDnsId; $resultMessage .= "Info: DNS dibuat/diperbarui (ID: $newDnsId). "; }
                  else { $domains[$domainIndex]['cloudflare_dns_id'] = null; $resultMessage .= "Peringatan: Gagal buat/update DNS saat aktifkan. "; }
             } elseif (($status === 'hidden' || $status === 'blocked') && !empty($originalDnsId)) {
                  if (deleteCloudflareDnsRecord($originalDnsId)) { $domains[$domainIndex]['cloudflare_dns_id'] = null; $resultMessage .= "Info: DNS dihapus (ID: $originalDnsId). "; }
                  else { $resultMessage .= "Peringatan: Gagal hapus DNS (ID: $originalDnsId). "; }
             }
             if ($status === 'blocked' && !in_array($currentDomainData['domain'], $blockedDomains)) { $blockedDomains[] = $currentDomainData['domain']; writeJsonFile(BLOCKED_LIST_FILE, $blockedDomains); }
             elseif ($status !== 'blocked' && ($key_blocked = array_search($currentDomainData['domain'], $blockedDomains)) !== false) { unset($blockedDomains[$key_blocked]); writeJsonFile(BLOCKED_LIST_FILE, array_values($blockedDomains)); }
         }
         if (writeJsonFile(DOMAIN_DATA_FILE, $domains)) { $resultMessage .= "Sukses: Domain '" . $currentDomainData['domain'] . "' diperbarui."; }
         else { $resultMessage .= "Error: Gagal menyimpan perubahan domain."; }

    } elseif ($action === 'delete_domain' && $domainIndex !== null && isset($domains[$domainIndex])) {
         $domainToDelete = $domains[$domainIndex]; $dnsIdToDelete = $domainToDelete['cloudflare_dns_id'] ?? null;
         if ($dnsIdToDelete) {
             if (deleteCloudflareDnsRecord($dnsIdToDelete)) { $resultMessage .= "Info: DNS Cloudflare (ID: $dnsIdToDelete) dihapus. "; }
             else { $resultMessage .= "Peringatan: Gagal hapus DNS Cloudflare (ID: $dnsIdToDelete). "; }
         }
         unset($domains[$domainIndex]); $domains = array_values($domains);
         if (writeJsonFile(DOMAIN_DATA_FILE, $domains)) {
              $resultMessage .= "Sukses: Domain '" . $domainToDelete['domain'] . "' dihapus.";
              if (($key_blocked = array_search($domainToDelete['domain'], $blockedDomains)) !== false) { unset($blockedDomains[$key_blocked]); writeJsonFile(BLOCKED_LIST_FILE, array_values($blockedDomains)); }
         } else { $resultMessage .= "Error: Gagal menyimpan data setelah hapus domain."; }
    }

     if (!empty($resultMessage)) {
         $formMessage = $resultMessage;
         $domains = readJsonFile(DOMAIN_DATA_FILE);
     }
}

?>
<h1><i class="fas fa-list-alt"></i> Manage Domains</h1>

<?php if ($formMessage): ?>
    <div class="message <?php
        if (strpos(strtolower($formMessage), 'error') !== false || strpos(strtolower($formMessage), 'gagal') !== false) echo 'error';
        elseif (strpos(strtolower($formMessage), 'sukses') !== false) echo 'success';
        elseif (strpos(strtolower($formMessage), 'peringatan') !== false) echo 'warning';
        else echo 'info'; ?>">
        <?php echo htmlspecialchars($formMessage); ?>
    </div>
<?php endif; ?>

<div class="container">
    <h2>Tambah / Edit Domain</h2>
    <form method="POST" id="domain-form" action="admin.php?page=manage_domains">
        <input type="hidden" name="action" id="form-action" value="add_domain">
        <input type="hidden" name="domain_index" id="form-domain-index" value="">

        <label for="domain">Domain:</label>
        <input type="text" id="form-domain" name="domain" required placeholder="contoh.com">

        <label for="nama">Nama:</label>
        <input type="text" id="form-nama" name="nama" placeholder="(Opsional) Nama Situs">

        <label for="brand">Brand:</label>
        <input type="text" id="form-brand" name="brand" required placeholder="BrandA">

        <label for="label">Label:</label>
        <input type="text" id="form-label" name="label" required placeholder="Utama / Alternatif">

        <label for="status">Status:</label>
        <select id="form-status" name="status">
            <option value="active">Active</option>
            <option value="hidden">Hidden</option>
            <option value="blocked">Blocked</option>
        </select>

        <button type="submit" id="form-submit-button">Tambah Domain</button>
        <button type="button" onclick="resetDomainForm()" style="background-color:#6c757d;">Batal Edit</button>
    </form>
</div>

<div class="container">
    <h2>Daftar Domain</h2>
    <?php if (!empty($domains)): ?>
    <div style="overflow-x:auto;">
    <table>
        <thead>
            <tr>
                <th>Domain</th>
                <th>Nama</th>
                <th>Brand</th>
                <th>Label</th>
                <th>Status</th>
                <th>CF DNS ID</th>
                <th>Aksi</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($domains as $index => $d): ?>
            <tr>
                <td><?php echo htmlspecialchars($d['domain']); ?></td>
                <td><?php echo htmlspecialchars($d['nama'] ?? ''); ?></td>
                <td><?php echo htmlspecialchars($d['brand']); ?></td>
                <td><?php echo htmlspecialchars($d['label']); ?></td>
                <td><?php echo htmlspecialchars($d['status']); ?></td>
                <td><?php echo htmlspecialchars($d['cloudflare_dns_id'] ?? 'N/A'); ?></td>
                <td class="action-buttons">
                    <button class="edit-button" onclick="editDomain(<?php echo $index; ?>, '<?php echo htmlspecialchars(json_encode($d), ENT_QUOTES); ?>')">Edit</button>
                    <form method="POST" action="admin.php?page=manage_domains" onsubmit="return confirm('Yakin hapus permanen domain <?php echo htmlspecialchars($d['domain']); ?>?')">
                        <input type="hidden" name="action" value="delete_domain">
                        <input type="hidden" name="domain_index" value="<?php echo $index; ?>">
                        <button type="submit" class="delete-button">Delete</button>
                    </form>
                </td>
            </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
    </div>
    <?php else: ?>
    <p>Belum ada domain.</p>
    <?php endif; ?>
</div>

<script>
function editDomain(index, domainDataJson) {
    const data = JSON.parse(domainDataJson);
    document.getElementById('form-action').value = 'update_domain';
    document.getElementById('form-domain-index').value = index;
    document.getElementById('form-domain').value = data.domain;
    document.getElementById('form-domain').readOnly = true;
    document.getElementById('form-nama').value = data.nama || '';
    document.getElementById('form-brand').value = data.brand;
    document.getElementById('form-label').value = data.label;
    document.getElementById('form-status').value = data.status;
    document.getElementById('form-submit-button').textContent = 'Update Domain';
    document.getElementById('domain-form').scrollIntoView({ behavior: 'smooth' });
}

function resetDomainForm() {
    document.getElementById('domain-form').reset();
    document.getElementById('form-action').value = 'add_domain';
    document.getElementById('form-domain-index').value = '';
    document.getElementById('form-domain').readOnly = false;
    document.getElementById('form-submit-button').textContent = 'Tambah Domain';
}
</script>
